@@ -8,15 +8,16 @@ import fast_histogram
 
 class Deskewer():
     def __init__(self):
-        self.thetas_step = 0.05
+        self.thetas_step = 0.02
         self.min_theta = 85
         self.max_theta = 95
-        self.num_rhos = 500
+        self.num_rhos = 2000
 
     def edge_detection(self, image):
         edge_image = cv2.cvtColor(image, cv2.COLOR_BGR2GRAY)
         edge_image = cv2.GaussianBlur(edge_image, (3, 3), 1)
-        edge_image = cv2.Canny(edge_image, 100, 200)
+        #edge_image = cv2.Canny(edge_image, 100, 200)
+        _, edge_image = cv2.threshold(edge_image, 0,255,cv2.THRESH_BINARY_INV+cv2.THRESH_OTSU)
         edge_image = cv2.dilate(
             edge_image,
             cv2.getStructuringElement(cv2.MORPH_RECT, (5, 5)),
@@ -33,9 +34,7 @@ class Deskewer():
         return edge_image
 
     def deskew(self, image):
-        edge_image = image[:image.shape[0]//2]
-
-        edge_image = self.edge_detection(edge_image)       
+        edge_image = self.edge_detection(image)       
         edge_height, edge_width = edge_image.shape[:2]
         edge_height_half, edge_width_half = edge_height / 2, edge_width / 2
 
